@@ -9,7 +9,7 @@
 #include <cplex_solver.h>
 #include <math.h>
 
-#define OUTPUT_MODEL 1
+#define OUTPUT_MODEL 0
 #define USEXNAME 0
 
 // solver creation 
@@ -43,14 +43,7 @@ int cplex_solver::init_solver(CUDFVersionedPackageList *all_versioned_packages,
     fprintf (stderr, "Failure to set EPGAP, error %d.\n", status);
     exit(-1);
   }
-
-  /* Limit the number of thread to 1 */  
-  status = CPXsetintparam (env, CPX_PARAM_THREADS, 1);
-  if ( status ) {
-    fprintf (stderr, "Failure to set thread limit to 1, error %d.\n", status);
-    exit(-1);
-  }
-
+  
   if (verbosity > 1) {
     /* Turn on output to the screen */
     status = CPXsetintparam (env, CPX_PARAM_SCRIND, CPX_ON);
